Crate serde_rmpv

Crate serde_rmpv 

Serde integration for the rmpv MessagePack Value type.

This crate handles all Serde data model types and includes special support for MessagePack’s Ext type through the MSGPACK_EXT_STRUCT_NAME type annotation.

Enums

Error

Constants

MSGPACK_EXT_STRUCT_NAME
Name of the Serde newtype struct to represent MessagePack’s Ext type

Functions

from_value
Deserializes rmpv::Value into a target type.
to_value
Serializes a type into rmpv::Value.