Serde integration for the rmpv MessagePack Value type.
This crate handles all Serde data model types and includes special support for MessagePack’s
Ext type through the MSGPACK_EXT_STRUCT_NAME type annotation.
Enums
Constants
- MSGPACK_
EXT_ STRUCT_ NAME - Name of the Serde newtype struct to represent MessagePack’s Ext type
Functions
- from_
value - Deserializes rmpv::Value into a target type.
- to_
value - Serializes a type into rmpv::Value.